==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/subversion/svnremovejob_p.h <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef KDEVPLATFORM_PLUGIN_SVNREMOVEJOB_P_H
#define KDEVPLATFORM_PLUGIN_SVNREMOVEJOB_P_H

#include "svninternaljobbase.h"

class SvnInternalRemoveJob : public SvnInternalJobBase
{
    Q_OBJECT
public:
    SvnInternalRemoveJob( SvnJobBase* parent = 0 );
    void setLocations( const KUrl::List& );
    void setForce( bool );

    KUrl::List locations() const;

    bool force() const;

protected:
    void run();
private:
    KUrl::List m_locations;
    bool m_force;
};


#endif

==> kdevplatform-4.90.90.tar.xz: kdevplatform-4.90.90/plugins/subversion/svnremovejob_p.h <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef KDEVPLATFORM_PLUGIN_SVNREMOVEJOB_P_H
#define KDEVPLATFORM_PLUGIN_SVNREMOVEJOB_P_H

#include "svninternaljobbase.h"

class SvnInternalRemoveJob : public SvnInternalJobBase
{
    Q_OBJECT
public:
    explicit SvnInternalRemoveJob( SvnJobBase* parent = 0 );
    void setLocations( const QList<QUrl>& );
    void setForce( bool );

    QList<QUrl> locations() const;

    bool force() const;

protected:
    void run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread* thread) override;
private:
    QList<QUrl> m_locations;
    bool m_force;
};


#endif
